pub struct ScriptStatsSnapshot {
pub mean_ms: f64,
pub p95_ms: f64,
pub max_ms: f64,
pub window_polls: u64,
pub total_polls: u64,
pub productive_polls: u64,
pub spent_ms: f64,
}Expand description
Mean, 95th percentile and worst case for the retained polls, in milliseconds.
Fields
mean_ms: f64p95_ms: f64max_ms: f64window_polls: u64Polls that ran script, out of the retained window.
total_polls: u64Every poll since launch.
productive_polls: u64Polls that ran script since launch.
spent_ms: f64Total time in the script runtime since launch, in milliseconds.